@@ -8,7 +8,7 @@ use argc::{
     Shell,
 };
 use base64::{engine::general_purpose, Engine as _};
-use std::{collections::HashMap, env, fs, process};
+use std::{collections::HashMap, env, fs, path::Path, process};
 use utils::*;
 use which::which;
 
@@ -56,15 +56,11 @@ fn run() -> Result<i32> {
                     code.push_str(&cmds.join(" "));
                     println!("{code}")
                 } else {
-                    let values = argc::eval(&source, &cmd_args, Some(&args[2]), termwidth())
-                        .map_err(|err| anyhow!("error: {err}"))?;
-                    let export_pwd = match env::var("ARGC_PWD").ok().or_else(get_current_dir) {
-                        Some(v) => format!("export ARGC_PWD={v}\n"),
-                        None => String::new(),
-                    };
+                    let values = argc::eval(&source, &cmd_args, Some(&args[2]), termwidth())?;
+                    let dir_vars = export_dir_vars(&args[2]);
                     let code = argc::ArgcValue::to_shell(&values);
                     let export_vars = export_argc_variables(&code);
-                    println!("{export_pwd}{export_vars}{code}")
+                    println!("{dir_vars}{export_vars}{code}")
                 }
             }
             "--argc-create" => {
@@ -91,7 +87,9 @@ fn run() -> Result<i32> {
                     None => bail!("Usage: argc --argc-completions <SHELL> [CMDS]..."),
                 };
                 let script = crate::completions::generate(shell, &args[3..])?;
-                println!("{}", script);
+                if !script.is_empty() {
+                    println!("{}", script);
+                }
             }
             "--argc-parallel" => {
                 if args.len() <= 3 {
@@ -158,26 +156,24 @@ fn run_compgen(mut args: Vec<String>) -> Option<()> {
     let shell: Shell = args.get(2).and_then(|v| v.parse().ok())?;
     if args[3].is_empty() {
         if args[4] == "argc" {
-            if let Some((_, script_file_)) = get_script_path(true) {
-                args[3] = script_file_.to_string_lossy().to_string();
+            if let Some((_, script_file)) = get_script_path(true) {
+                args[3] = script_file.to_string_lossy().to_string();
             }
-        } else if let Ok(script_file_) = which(&args[4]) {
-            args[3] = script_file_.to_string_lossy().to_string();
-        } else {
-            return None;
+        } else if let Some(script_file) = search_completion_script(&mut args) {
+            args[3] = script_file.to_string_lossy().to_string();
+        } else if let Ok(script_file) = which(&args[4]) {
+            args[3] = script_file.to_string_lossy().to_string();
         }
     }
-    let no_color = if let Ok(v) = std::env::var("NO_COLOR") {
-        v == "true" || v == "1"
-    } else {
-        false
-    };
-    let output = if args.len() >= 6
-        && &args[4] == "argc"
-        && (args[3].is_empty() || args[5].starts_with("--argc"))
-    {
+    let no_color = std::env::var("NO_COLOR")
+        .map(|v| v == "true" || v == "1")
+        .unwrap_or_default();
+    let output = if &args[4] == "argc" && (args[3].is_empty() || args[5].starts_with("--argc")) {
         let cmd_args = &args[4..];
         argc::compgen(shell, "", COMPLETION_SCRIPT, cmd_args, no_color).ok()?
+    } else if args[3].is_empty() {
+        let cmd_args = &args[4..];
+        argc::compgen(shell, "", "# @arg path*", cmd_args, no_color).ok()?
     } else {
         let (source, cmd_args) = parse_script_args(&args[3..]).ok()?;
         argc::compgen(shell, &args[3], &source, &cmd_args[1..], no_color).ok()?
@@ -240,3 +236,28 @@ fn get_argc_version() -> String {
     let version = env!("CARGO_PKG_VERSION");
     format!("{name} {version}")
 }
+
+fn export_dir_vars(path: &str) -> String {
+    if let (Some(argc_script_dir), Some(cwd)) = (
+        get_argc_script_dir(path),
+        env::var("ARGC_PWD").ok().or_else(get_current_dir),
+    ) {
+        let cd = if argc_script_dir != cwd {
+            format!("cd {}\n", escape_shell_words(&argc_script_dir))
+        } else {
+            String::new()
+        };
+        format!("{}export ARGC_PWD={}\n", cd, escape_shell_words(&cwd))
+    } else {
+        String::new()
+    }
+}
+
+fn get_argc_script_dir(path: &str) -> Option<String> {
+    if candidate_script_names().iter().all(|v| !path.ends_with(v)) {
+        return None;
+    }
+    let script_file = fs::canonicalize(Path::new(path)).ok()?;
+    let script_dir = script_file.parent()?;
+    Some(script_dir.display().to_string())
+}
