@@ -9,10 +9,11 @@ use serde_json::json;
 #[derive(Debug, PartialEq, Eq, Clone)]
 pub(crate) struct FlagOptionParam {
     pub(crate) describe: String,
-    pub(crate) short: Option<char>,
     pub(crate) flag: bool,
-    pub(crate) single_hyphen: bool,
+    pub(crate) short: Option<String>,
+    pub(crate) long_prefix: String,
     pub(crate) data: ParamData,
+    pub(crate) var_name: String,
     pub(crate) value_names: Vec<String>,
     pub(crate) arg_value_names: Vec<String>,
     pub(crate) inherit: bool,
@@ -22,17 +23,22 @@ impl FlagOptionParam {
     pub(crate) fn new(
         param: ParamData,
         describe: &str,
-        short: Option<char>,
         flag: bool,
-        single_hyphen: bool,
+        short: Option<&str>,
+        long_prefix: &str,
         value_names: &[&str],
     ) -> Self {
-        let name = param.name.clone();
+        let param_name = param.name.clone();
+        let var_name = if long_prefix.starts_with('+') {
+            format!("plus_{}", param_name)
+        } else {
+            param_name.clone()
+        };
         let value_names: Vec<String> = value_names.iter().map(|v| v.to_string()).collect();
         let mut arg_value_names = if flag {
             vec![]
         } else if value_names.is_empty() {
-            vec![to_cobol_case(&name)]
+            vec![to_cobol_case(&param_name)]
         } else {
             value_names.iter().map(|v| to_cobol_case(v)).collect()
         };
@@ -42,18 +48,19 @@ impl FlagOptionParam {
         }
         Self {
             describe: describe.to_string(),
-            short,
             flag,
-            single_hyphen,
+            short: short.map(|v| v.to_string()),
+            long_prefix: long_prefix.to_string(),
             data: param,
+            var_name,
             value_names,
             arg_value_names,
             inherit: false,
         }
     }
 
-    pub(crate) fn name(&self) -> &str {
-        self.data.name.as_str()
+    pub(crate) fn var_name(&self) -> &str {
+        &self.var_name
     }
 
     pub(crate) fn is_flag(&self) -> bool {
@@ -85,32 +92,33 @@ impl FlagOptionParam {
     }
 
     pub(crate) fn unlimited_args(&self) -> bool {
-        self.terminated() || !self.notation_modifer().is_none()
+        self.terminated()
+            || self
+                .notation_modifer()
+                .map(|v| "*+".contains(v))
+                .unwrap_or_default()
     }
 
     pub(crate) fn validate_args_len(&self, num: usize) -> bool {
         let len = self.arg_value_names.len();
         if self.unlimited_args() {
-            let min = if len > 1 && self.notation_modifer() == NotationModifier::Asterisk {
+            let min = if self.notation_modifer() == Some('*') {
                 len - 1
             } else {
                 len
             };
             num >= min
+        } else if self.notation_modifer() == Some('?') {
+            num == len || num == len - 1
         } else {
             num == len
         }
     }
 
-    pub(crate) fn notation_modifer(&self) -> NotationModifier {
-        if let Some(notation) = self.arg_value_names.last() {
-            if notation.ends_with('*') {
-                return NotationModifier::Asterisk;
-            } else if notation.ends_with('+') {
-                return NotationModifier::Plus;
-            }
-        }
-        NotationModifier::None
+    pub(crate) fn notation_modifer(&self) -> Option<char> {
+        self.arg_value_names
+            .last()
+            .and_then(|name| ['*', '+', '?'].into_iter().find(|v| name.ends_with(*v)))
     }
 
     pub(crate) fn required(&self) -> bool {
@@ -134,14 +142,14 @@ impl FlagOptionParam {
     }
 
     #[allow(unused)]
-    pub(crate) fn render(&self) -> String {
+    pub(crate) fn render_source(&self) -> String {
         let mut output = vec![];
-        if let Some(ch) = self.short {
-            output.push(format!("-{}", ch));
+        if let Some(short) = &self.short {
+            output.push(short.to_string());
         };
         output.push(format!(
             "{}{}",
-            self.render_hyphens(),
+            self.long_prefix,
             self.data.render_name_value()
         ));
         for value_name in &self.value_names {
@@ -153,47 +161,35 @@ impl FlagOptionParam {
         output.join(" ")
     }
 
-    pub(crate) fn render_hyphens(&self) -> &str {
-        if self.single_hyphen {
-            "-"
-        } else {
-            "--"
-        }
-    }
-
     pub(crate) fn render_name(&self) -> String {
-        format!("{}{}", self.render_hyphens(), self.name())
+        format!("{}{}", self.long_prefix, self.data.name)
     }
 
-    pub(crate) fn render_first_value(&self) -> String {
+    pub(crate) fn render_first_notation(&self) -> String {
         format!("<{}>", self.arg_value_names[0])
     }
 
-    pub(crate) fn render_name_values(&self) -> String {
+    pub(crate) fn render_name_notations(&self) -> String {
         let mut output = self.render_name();
         if !self.is_flag() {
             output.push(' ');
-            output.push_str(&self.render_arg_values());
+            output.push_str(&self.render_notations());
         }
         output
     }
 
     pub(crate) fn render_body(&self) -> String {
         let mut output = String::new();
-        if self.single_hyphen && self.short.is_none() && self.name().len() == 1 {
-            output.push_str(&format!("-{}", self.name()));
+        if self.short.is_none() && self.long_prefix.len() == 1 && self.data.name.len() == 1 {
+            output.push_str(&self.render_name());
         } else {
-            if let Some(ch) = self.short {
-                output.push_str(&format!("-{ch}, "))
+            if let Some(short) = &self.short {
+                output.push_str(&format!("{short}, "))
             } else {
                 output.push_str("    ")
             };
-            if self.single_hyphen {
-                output.push_str(" -")
-            } else {
-                output.push_str("--")
-            }
-            output.push_str(self.name());
+            output.push_str(&format!("{:>2}", self.long_prefix));
+            output.push_str(&self.data.name);
         }
 
         if self.is_flag() {
@@ -202,33 +198,33 @@ impl FlagOptionParam {
             }
         } else {
             output.push(' ');
-            output.push_str(&self.render_arg_values());
+            output.push_str(&self.render_notations());
         }
         output
     }
 
-    pub(crate) fn render_arg_values(&self) -> String {
+    pub(crate) fn render_notations(&self) -> String {
         if self.is_flag() {
             return String::new();
         }
-        let output = self
-            .arg_value_names
-            .iter()
-            .map(|v| {
-                if self.multi_occurs() {
-                    v.to_string()
-                } else {
-                    format!("<{v}>")
-                }
-            })
-            .collect::<Vec<String>>()
-            .join(" ");
-
-        if self.multi_occurs() {
-            format!("[{output}]...")
+        let mut output = String::new();
+        if self.arg_value_names.len() == 1 {
+            let name: &String = &self.arg_value_names[0];
+            let value = match (self.required(), self.multi_occurs()) {
+                (true, true) => format!("<{name}>..."),
+                (false, true) => format!("[{name}]..."),
+                (_, false) => format!("<{name}>"),
+            };
+            output.push_str(&value);
         } else {
-            output
+            let values = self
+                .arg_value_names
+                .iter()
+                .map(|v| format!("<{v}>"))
+                .collect::<Vec<String>>();
+            output.push_str(&values.join(" "));
         }
+        output
     }
 
     pub(crate) fn render_describe(&self) -> String {
@@ -236,21 +232,21 @@ impl FlagOptionParam {
     }
 
     pub(crate) fn get_arg_value(&self, values: &[&[&str]]) -> Option<ArgcValue> {
-        let name = self.name().to_string();
+        let var_name = self.var_name().to_string();
         if self.flag {
             if values.is_empty() {
                 None
             } else {
-                Some(ArgcValue::Single(name, values.len().to_string()))
+                Some(ArgcValue::Single(var_name, values.len().to_string()))
             }
         } else {
             if values.is_empty() {
                 match &self.data.default {
                     Some(DefaultData::Value(value)) => {
-                        return Some(ArgcValue::Single(name, value.clone()));
+                        return Some(ArgcValue::Single(var_name, value.clone()));
                     }
                     Some(DefaultData::Fn(f)) => {
-                        return Some(ArgcValue::SingleFn(name, f.clone()));
+                        return Some(ArgcValue::SingleFn(var_name, f.clone()));
                     }
                     None => return None,
                 }
@@ -271,20 +267,20 @@ impl FlagOptionParam {
                         })
                         .collect()
                 }
-                Some(ArgcValue::Multiple(name, values))
+                Some(ArgcValue::Multiple(var_name, values))
             } else if self.arg_value_names.len() > 1 {
                 Some(ArgcValue::Multiple(
-                    name,
+                    var_name,
                     values[0].iter().map(|v| v.to_string()).collect(),
                 ))
             } else {
-                Some(ArgcValue::Single(name, must_get_first(values[0])))
+                Some(ArgcValue::Single(var_name, must_get_first(values[0])))
             }
         }
     }
 
     pub(crate) fn is_match(&self, name: &str) -> bool {
-        self.list_names().iter().any(|v| v == name)
+        self.list_option_names().iter().any(|v| v == name)
     }
 
     pub(crate) fn prefixed(&self) -> Option<String> {
@@ -295,23 +291,23 @@ impl FlagOptionParam {
             return None;
         }
 
-        if let Some(ch) = self.short {
-            return Some(format!("-{ch}"));
+        if let Some(short) = &self.short {
+            return Some(short.clone());
         }
 
         Some(self.render_name())
     }
 
-    pub(crate) fn list_names(&self) -> Vec<String> {
+    pub(crate) fn list_option_names(&self) -> Vec<String> {
         let mut output = vec![];
-        output.push(format!("{}{}", self.render_hyphens(), self.name()));
-        if let Some(short) = self.short {
-            output.push(format!("-{}", short));
+        output.push(self.render_name());
+        if let Some(short) = &self.short {
+            output.push(short.clone());
         }
         output
     }
 
-    pub(crate) fn describe_head(&self) -> &str {
+    pub(crate) fn describe_oneline(&self) -> &str {
         match self.describe.split_once('\n') {
             Some((v, _)) => v,
             None => self.describe.as_str(),
@@ -319,16 +315,16 @@ impl FlagOptionParam {
     }
 
     pub fn to_json(&self) -> serde_json::Value {
-        let option_names = self.list_names();
+        let option_names = self.list_option_names();
         json!({
-            "name": self.name(),
+            "name": self.data.name,
             "describe": self.describe,
             "flag": self.flag,
             "option_names": option_names,
             "value_names": self.value_names,
             "modifier": self.data.modifer,
             "choices": self.data.choice_values(),
-            "default": self.data.defualt_value(),
+            "default": self.data.default_value(),
         })
     }
 }
@@ -355,7 +351,7 @@ impl PositionalParam {
         }
     }
 
-    pub(crate) fn name(&self) -> &str {
+    pub(crate) fn var_name(&self) -> &str {
         &self.data.name
     }
 
@@ -388,7 +384,7 @@ impl PositionalParam {
     }
 
     #[allow(unused)]
-    pub(crate) fn render(&self) -> String {
+    pub(crate) fn render_source(&self) -> String {
         let mut output = vec![];
         output.push(self.data.render_name_value());
         if let Some(value_name) = self.value_name.as_ref() {
@@ -415,7 +411,7 @@ impl PositionalParam {
     }
 
     pub(crate) fn get_arg_value(&self, values: &[&str]) -> Option<ArgcValue> {
-        let name = self.name().to_string();
+        let name = self.var_name().to_string();
         if values.is_empty() {
             match &self.data.default {
                 Some(DefaultData::Value(value)) => {
@@ -446,7 +442,7 @@ impl PositionalParam {
         }
     }
 
-    pub(crate) fn describe_head(&self) -> &str {
+    pub(crate) fn describe_oneline(&self) -> &str {
         match self.describe.split_once('\n') {
             Some((v, _)) => v,
             None => self.describe.as_str(),
@@ -455,14 +451,15 @@ impl PositionalParam {
 
     pub fn to_json(&self) -> serde_json::Value {
         json!({
-            "name": self.name(),
+            "name": self.var_name(),
             "describe": self.describe,
             "modifier": self.data.modifer,
             "choices": self.data.choice_values(),
-            "default": self.data.defualt_value(),
+            "default": self.data.default_value(),
         })
     }
 }
+
 #[derive(Debug, PartialEq, Eq, Clone)]
 pub(crate) struct ParamData {
     pub(crate) name: String,
@@ -521,7 +518,7 @@ impl ParamData {
         }
     }
 
-    pub(crate) fn defualt_value(&self) -> Option<&String> {
+    pub(crate) fn default_value(&self) -> Option<&String> {
         match &self.default {
             Some(DefaultData::Value(v)) => Some(v),
             _ => None,
@@ -539,8 +536,8 @@ impl ParamData {
                 result.push_str(&format!("[={}]", Self::render_choice_values(values)));
             }
             (Some(ChoiceData::Fn(f, validate)), _) => {
-                let sign = if *validate { "" } else { "?" };
-                result.push_str(&format!("[{sign}`{f}`]"));
+                let prefix = if *validate { "" } else { "?" };
+                result.push_str(&format!("[{prefix}`{f}`]"));
             }
             (None, Some(DefaultData::Value(value))) => {
                 result.push_str(&format!("={}", Self::render_default_value(value)));
@@ -594,20 +591,6 @@ impl ParamData {
     }
 }
 
-#[derive(Debug, PartialEq, Eq, Clone, Serialize)]
-#[serde(tag = "type", content = "value")]
-pub(crate) enum NotationModifier {
-    None,
-    Plus,
-    Asterisk,
-}
-
-impl NotationModifier {
-    pub(crate) fn is_none(&self) -> bool {
-        self == &NotationModifier::None
-    }
-}
-
 #[derive(Debug, PartialEq, Eq, Clone, Serialize)]
 #[serde(tag = "type", content = "value")]
 pub(crate) enum Modifier {
