@@ -79,6 +79,47 @@ fn shorts() {
     );
 }
 
+#[test]
+fn symbol() {
+    let script = r###"
+# @meta symbol +toolchain[`_choice_fn`]
+# @meta symbol @file
+# @option --oa
+
+_choice_fn() {
+    echo stable
+    echo beta
+    echo nightly
+}
+"###;
+    snapshot_compgen!(
+        script,
+        [vec!["prog", "+"], vec!["prog", "@"], vec!["prog", "+s"]]
+    );
+}
+
+#[test]
+fn plus_sign() {
+    let script = r#"
+# @flag +a
+# @option +fb[abc|def|ijk]
+# @option +c +fc*[`_choice_fn`]
+# @option +d -fd*[`_choice_fn`]
+_choice_fn() {
+	echo -e "abc\ndef\nghi"
+}
+"#;
+    snapshot_compgen!(
+        script,
+        [
+            vec!["prog", "+"],
+            vec!["prog", "+fb="],
+            vec!["prog", "+fc", ""],
+            vec!["prog", "-fd", ""],
+        ]
+    );
+}
+
 #[test]
 fn subcmds() {
     const SCRIPT: &str = r###"
@@ -497,6 +538,23 @@ _choice_fn() {
     snapshot_compgen_shells!(script, ["prog", "--oa", ""]);
 }
 
+#[test]
+fn value() {
+    let script = r#"
+# @option --oa[`_choice_fn`]
+_choice_fn() {
+    echo "abc def"
+    echo "abc xyz"
+    echo "abc:def"
+    echo "abc:xyz"
+    echo "abc>def"
+    echo "abc>xyz"
+}
+"#;
+
+    snapshot_compgen_shells!(script, ["prog", "--oa", "abc"]);
+}
+
 #[test]
 fn value_display() {
     let script = r#"
@@ -730,7 +788,7 @@ abc() { :; }
 }
 
 #[test]
-fn mult_char() {
+fn multi_char() {
     let script = r#"
 # @option --oa*,[`_choice_fn`]
 _choice_fn() {
@@ -742,7 +800,7 @@ _choice_fn() {
 }
 
 #[test]
-fn mult_char2() {
+fn multi_char2() {
     let script = r#"
 # @option --oa*,[`_choice_fn`]
 _choice_fn() {
