@@ -7,7 +7,7 @@ macro_rules! eval {
     ) => {
         let args: Vec<String> = $args.iter().map(|v| v.to_string()).collect();
         let values = argc::eval(None, $source, &args, None).unwrap();
-        let shell_code = argc::ArgcValue::to_shell(values);
+        let shell_code = argc::ArgcValue::to_shell(&values);
         assert_eq!(shell_code, $output);
     };
 }
@@ -41,7 +41,7 @@ macro_rules! snapshot {
     ) => {
         let args: Vec<String> = $args.iter().map(|v| v.to_string()).collect();
         let values = argc::eval($source, &args, $path, $width).unwrap();
-        let shell_code = argc::ArgcValue::to_shell(values);
+        let shell_code = argc::ArgcValue::to_shell(&values);
         let args = $args.join(" ");
         let data = format!(
             r###"RUN
@@ -79,7 +79,7 @@ OUTPUT
 
 "###,
                 args,
-                argc::ArgcValue::to_shell(values),
+                argc::ArgcValue::to_shell(&values),
             );
             data.push_str(&piece);
         }
@@ -100,7 +100,7 @@ macro_rules! snapshot_compgen {
             $crate::fixtures::create_argc_script($source, "compgen.sh");
         for args in $matrix.iter() {
             let args: Vec<String> = args.iter().map(|v| v.to_string()).collect();
-            let words = match argc::compgen($shell, &script_path, &script_content, &args) {
+            let words = match argc::compgen($shell, &script_path, &script_content, &args, false) {
                 Ok(stdout) => stdout,
                 Err(stderr) => stderr.to_string(),
             };
@@ -121,7 +121,7 @@ macro_rules! snapshot_compgen {
 		$source:expr,
         $matrix:expr
     ) => {
-        snapshot_compgen!($source, $matrix, argc::Shell::Fish);
+        snapshot_compgen!($source, $matrix, argc::Shell::Generic);
     };
 }
 
@@ -136,7 +136,7 @@ macro_rules! snapshot_compgen_shells {
             $crate::fixtures::create_argc_script($source, "compgen.sh");
         let args: Vec<String> = $args.iter().map(|v| v.to_string()).collect();
         for shell in argc::Shell::list() {
-            let words = match argc::compgen(shell, &script_path, &script_content, &args) {
+            let words = match argc::compgen(shell, &script_path, &script_content, &args, false) {
                 Ok(stdout) => stdout,
                 Err(stderr) => stderr.to_string(),
             };
